:mod:`art.defences.transformer`
===============================
.. automodule:: art.defences.transformer

Transformer
-----------
.. autoclass:: Transformer
   :members:
   :special-members:

Defensive Distillation
----------------------
.. autoclass:: DefensiveDistillation
   :members:
   :special-members:
